
function [x,U]=min_primitiv(f,I,ua,h)
% min_primitiv - löser begynnelsevärdesproblemet u'(x)=f(x), u(a)=ua
%
%   Syntax:
%           [x,U]=min_primitiv(f,I,ua,h)
%   Argument:
%           f   - funktionshandtag: pekar på namnet till en funktionsfil eller
%                 till en anonym funktion, t.ex. f=@funk
%           I   - 1x2 matris, anger ett intervall I=[a b]
%           ua  - ett tal, anger begynnelsevärdet
%           h   - positivt tal, anger steglängden
%   Returnerar:
%           x -  en kolonnvektor, beräkningsnoderna x(i)
%           U -  en kolonnvektor, U(i) är approximationen i
%                punkten x(i)
%   Beskrivning:
%           Programmet beräknar en approximativ lösning av begynnelsevärdes-
%           problemet  u'(x)=f(x), a<x<b; u(a)=ua, med Eulers metod.
%           Programmet använder konstant steglängd h.
%   Exampel:
%           [x,U]=min_primitiv(@cos, [0, pi/2], 0, 1e-3)
%           beräknar en approximation av sin(x).
%           plot(x,U) ritar lösningen.

...
